@@ -15,7 +15,8 @@ logger = logging.getLogger(__name__)
 
 
 if TYPE_CHECKING:
-    from .fs.base import AnyFSPath, FileSystem
+    from dvc_objects.fs.base import AnyFSPath, FileSystem
+
     from .state import StateBase
 
 
